#include <coleco.h>
#include <getput1.h>

void nmi(void) {}

void main(void)
{
	screen_mode_2_text();
    fill_vram0(0x2000,0x1800,0xf0);
	upload_default_ascii(BOLD_ITALIC);
    duplicate_pattern();
	cls();
	print_at(1,0,"SCREEN #1");
	screen(name_table1,name_table2);
	cls();
	print_at(1,0,"SCREEN #2");
loop:
	screen(name_table2,name_table1);
	print_at(rnd_byte(1,30),rnd_byte(1,22),"1");
	delay(5);
	screen(name_table1,name_table2);
	print_at(rnd_byte(1,30),rnd_byte(1,22),"2");
	delay(5);
	goto loop;
}